==> openjdk-17_17.0.17~8ea.orig.tar.xz: openjdk-17-17.0.17~8ea/test/jdk/sun/security/x509/Extensions/DefaultCriticality.java <==
/*
 * Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @summary Change default criticality of policy mappings and policy constraints
            certificate extensions
 * @bug 8059916
 * @modules java.base/sun.security.x509
 */

import sun.security.x509.PolicyConstraintsExtension;
import sun.security.x509.PolicyMappingsExtension;

public class DefaultCriticality {
    public static void main(String [] args) throws Exception {
        PolicyConstraintsExtension pce = new PolicyConstraintsExtension(-1,-1);
        if (!pce.isCritical()) {
            throw new Exception("PolicyConstraintsExtension should be " +
                                "critical by default");
        }

        PolicyMappingsExtension pme = new PolicyMappingsExtension();
        if (!pme.isCritical()) {
            throw new Exception("PolicyMappingsExtension should be " +
                                "critical by default");
        }

        System.out.println("Test passed.");
    }
}

==> openjdk-21_21.0.9~8ea.orig.tar.xz: openjdk-21-21.0.9~8ea/test/jdk/sun/security/x509/Extensions/DefaultCriticality.java <==
/*
 * Copyright (c) 2015, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @summary Change default criticality of policy mappings and policy constraints
            certificate extensions
 * @bug 8059916
 * @modules java.base/sun.security.x509
 *          java.base/sun.security.util
 */

import sun.security.util.ObjectIdentifier;
import sun.security.x509.CertificatePolicyId;
import sun.security.x509.CertificatePolicyMap;
import sun.security.x509.PolicyConstraintsExtension;
import sun.security.x509.PolicyMappingsExtension;

import java.util.List;

public class DefaultCriticality {
    public static void main(String [] args) throws Exception {
        PolicyConstraintsExtension pce = new PolicyConstraintsExtension(1, 1);
        if (!pce.isCritical()) {
            throw new Exception("PolicyConstraintsExtension should be " +
                                "critical by default");
        }

        CertificatePolicyId id = new CertificatePolicyId(ObjectIdentifier.of("1.2.3.4"));
        PolicyMappingsExtension pme = new PolicyMappingsExtension(List.of(
                new CertificatePolicyMap(id, id)));
        if (!pme.isCritical()) {
            throw new Exception("PolicyMappingsExtension should be " +
                                "critical by default");
        }

        System.out.println("Test passed.");
    }
}
